Skip to contents

Transform sample model output into a forecast object

Usage

transform_sample_model_out(
  model_out_tbl,
  oracle_output,
  compound_taskid_set = NULL
)

Arguments

model_out_tbl

Model output tibble with predictions

oracle_output

Predictions that would have been generated by an oracle model that knew the observed target data values in advance

compound_taskid_set

Character vector of task ID column names that stay constant within each sample draw (i.e., define the compound modeling task grouping). When NULL (the default), each modeling task is scored independently (marginal scoring). When provided, sample draws are treated as joint predictions across the task ID dimensions not in compound_taskid_set, and multivariate scoring metrics are used.

Value

A forecast_sample object (when compound_taskid_set is NULL) or a forecast_sample_multivariate object (when compound_taskid_set is provided).