Transform sample model output into a forecast object
transform_sample_model_out.RdTransform sample model output into a forecast object
Arguments
- model_out_tbl
Model output tibble with predictions
- oracle_output
Predictions that would have been generated by an oracle model that knew the observed target data values in advance
- compound_taskid_set
Character vector of task ID column names that stay constant within each sample draw (i.e., define the compound modeling task grouping). When
NULL(the default), each modeling task is scored independently (marginal scoring). When provided, sample draws are treated as joint predictions across the task ID dimensions not incompound_taskid_set, and multivariate scoring metrics are used.